print("import: 'uc_micro'")
import uc_micro

print("import: 'uc_micro.categories'")
import uc_micro.categories

print("import: 'uc_micro.categories.Cc'")
import uc_micro.categories.Cc

print("import: 'uc_micro.categories.Cf'")
import uc_micro.categories.Cf

print("import: 'uc_micro.categories.P'")
import uc_micro.categories.P

print("import: 'uc_micro.categories.Z'")
import uc_micro.categories.Z

print("import: 'uc_micro.properties'")
import uc_micro.properties

print("import: 'uc_micro.properties.Any'")
import uc_micro.properties.Any

